<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">
  <xsl:output method="html"/>
  <xsl:template match="/">
  
    <xsl:if test="ContextSet/context">
      <ul>
        <xsl:apply-templates select="ContextSet/context">
          <xsl:sort select="@name"/>
        </xsl:apply-templates>
      </ul>
    </xsl:if>
    
    <!-- build the item list in two parts: first group the famliy items, then output the rest -->
    <xsl:if test="ItemSet/item[@family]">
        <xsl:variable name="node" select="/"/>
        <xsl:for-each select="distinct-values(//item/@family)">
          <xsl:sort select="."/>
          <xsl:variable name="family" select="."/>
            <a style="TEXT-DECORATION: underline; font-size: 16px; font-weight: 300; margin: 10px" href="javascript:toggleLayer('{$family}');" title='Show/Hide items for family "{$family}"'>
              <xsl:value-of select="$family"/>
            </a>
            <br/>
          <div style="display: none;" id="{$family}">
            <table style="margin: 30px" border="0">
              <xsl:apply-templates select="$node/ItemSet/item[@family=$family]">
                <xsl:sort select="@name"/>
              </xsl:apply-templates>
            </table>
          </div>
        </xsl:for-each>
    </xsl:if>
    <br/><br/>
    <xsl:if test="ItemSet/item[not(@family)]">
      <table style="margin: 0px" border="0">
        <xsl:apply-templates select="ItemSet/item[not(@family)]">
          <xsl:sort select="@name"/>
        </xsl:apply-templates>
      </table>
    </xsl:if>
    
    <xsl:if test="SpacecraftSet/spacecraft">
      <ul>
        <xsl:apply-templates select="SpacecraftSet/spacecraft">
          <xsl:sort select="@name"/>
        </xsl:apply-templates>
      </ul>
    </xsl:if>
    
    <xsl:if test="MissionSet/mission">
      <ul>
        <xsl:apply-templates select="MissionSet/mission">
          <xsl:sort select="@name"/>
        </xsl:apply-templates>
      </ul>
    </xsl:if>
    
    <xsl:if test="InstrumentSet/instrument">
      <ul>
        <xsl:apply-templates select="InstrumentSet/instrument">
          <xsl:sort select="@name"/>
        </xsl:apply-templates>
      </ul>
    </xsl:if>
    
    <xsl:if test="EventSet/event">
      <ul>
        <xsl:apply-templates select="EventSet/event">
          <xsl:sort select="@name"/>
        </xsl:apply-templates>
      </ul>
    </xsl:if>
    
    <xsl:if test="ErrorSet/error">
      <xsl:apply-templates select="ErrorSet/error"/>
    </xsl:if>
    
  </xsl:template>

<!-- an error entry. if the webapp gets an error, report it to the user -->
  <xsl:template match="error">
    <font color="#ff0000">
      <xsl:text>Error Messsage: </xsl:text>
      <xsl:value-of select="."/>
    </font>
  </xsl:template>
  
<!-- An item entry. Used for listing the contents of an item file --> 
  <xsl:template match="item">
  <xsl:variable name="currentItem" select="@name"/>
  <xsl:if test="not(@name=following::item/@name)">
    <xsl:if test="not(@hidden) or @hidden = '0'">
    <tr><td>
      <ul id="item">
        <li style="MARGIN: 0px; BORDER-LEFT: #fff 0px solid; BORDER-BOTTOM: #999 1px solid;"><h2><xsl:value-of select="@name"/></h2></li>
        <li><b><xsl:text>Description: </xsl:text></b><xsl:value-of select="@description"/></li>
        <!-- determine item availability, based on the presence of a validity attribute -->
        <xsl:choose>
          <xsl:when test="@validity and count(//item[@name=$currentItem]) > 1">
            <li><b><xsl:text>Probably Present</xsl:text></b></li>
          </xsl:when>
          <xsl:when test="@validity">
            <li><b><xsl:text>Not Always Present</xsl:text></b></li>
          </xsl:when>
          <xsl:otherwise>
            <li><b><xsl:text>Always Present</xsl:text></b></li>
          </xsl:otherwise>
        </xsl:choose>
        <li>
          <xsl:variable name="uppercaseFixedValue" select="upper-case(@fixed_value)"/>
          <xsl:choose>
            <xsl:when test="@dim">
              <b><xsl:value-of select="@dim"/></b>
            </xsl:when>
            <xsl:when test="@repetitionsInSingleDataBlock != '1' or contains($uppercaseFixedValue, 'I4GEN') or contains($uppercaseFixedValue, 'R4GEN') or contains($uppercaseFixedValue, 'R8GEN') or contains($uppercaseFixedValue, 'I4VECTOR') or contains($uppercaseFixedValue, 'R4VECTOR') or contains($uppercaseFixedValue, 'R8VECTOR')">
              <b><xsl:text>Vector</xsl:text></b>
            </xsl:when>
            <xsl:otherwise>
              <b><xsl:text>Scalar</xsl:text></b>
            </xsl:otherwise>
          </xsl:choose>
        </li>
        <xsl:variable name="uppercaseType" select="upper-case(@dataType)"/>
        <li><b><xsl:text>Type(s): </xsl:text></b>
          <table>
            <tr>
              <td>
                <xsl:choose>
                  <xsl:when test="$uppercaseType = 'INTEGER'">
                    <xsl:value-of select="'Integer (I4)'"/>
                  </xsl:when>
                  <xsl:when test="$uppercaseType = 'FLOAT'">
                    <xsl:value-of select="'Float (R4)'"/>
                  </xsl:when>
                  <xsl:when test="$uppercaseType = 'DOUBLE'">
                    <xsl:value-of select="'Double (R8)'"/>
                  </xsl:when>
                </xsl:choose>
              </td>
            </tr>
              <xsl:if test="//item/xlate[parent::item/@name=$currentItem]">
                <tr>
                  <td>
                    <xsl:text>String (Char) </xsl:text>
                    <xsl:for-each select="distinct-values(//item/xlate[parent::item/@name=$currentItem]/@string)">
                      <xsl:text>"</xsl:text><xsl:value-of select="."/><xsl:text>" </xsl:text>
                    </xsl:for-each>
                  </td>
                </tr>
              </xsl:if>
          </table>
        </li>
      </ul>
      </td></tr>
    </xsl:if>
  </xsl:if>
  </xsl:template>

<!-- An event entry. -->
  <xsl:template match="event">
    <ul id="item">
      <li style="MARGIN: 0px; BORDER-LEFT: #fff 0px solid; BORDER-BOTTOM: #999 1px solid;"><h2><xsl:value-of select="@name"/></h2></li>
      <li><b><xsl:text>Description: </xsl:text></b><xsl:value-of select="@description"/></li>
    </ul>
    <br/><br/><br/><br/>
  </xsl:template>
  
<!-- An instrument entry. -->
  <xsl:template match="instrument">
    <ul id="item">
      <li style="MARGIN: 0px; BORDER-LEFT: #fff 0px solid; BORDER-BOTTOM: #999 1px solid;"><h2><xsl:value-of select="@name"/></h2></li>
      <li><b><xsl:text>Description: </xsl:text></b><xsl:value-of select="@description"/></li>
    </ul>
    <br/><br/><br/><br/>
  </xsl:template>
  
<!-- A mission entry. -->
  <xsl:template match="mission">
    <ul id="item">
      <li style="MARGIN: 0px; BORDER-LEFT: #fff 0px solid; BORDER-BOTTOM: #999 1px solid;"><h2><xsl:value-of select="@name"/></h2></li>
      <li><b><xsl:text>Description: </xsl:text></b><xsl:value-of select="@description"/></li>
    </ul>
    <br/><br/><br/><br/>
  </xsl:template>
  
<!-- A context entry. -->
  <xsl:template match="context">
    <ul id="item">
      <li style="MARGIN: 0px; BORDER-LEFT: #fff 0px solid; BORDER-BOTTOM: #999 1px solid;"><h2><xsl:value-of select="@name"/></h2></li>
      <li><b><xsl:text>StreamType: </xsl:text><xsl:value-of select="@streamtype"/></b></li>
      <li><b><xsl:text>Description: </xsl:text></b><xsl:value-of select="@description"/></li>
    </ul>
    <br/><br/><br/><br/>
  </xsl:template>
  
<!-- A spacecraft entry. -->
  <xsl:template match="spacecraft">
    <ul id="item">
      <li style="MARGIN: 0px; BORDER-LEFT: #fff 0px solid; BORDER-BOTTOM: #999 1px solid;"><h2><xsl:value-of select="@name"/></h2></li>
      <li><b><xsl:text>Description: </xsl:text></b><xsl:value-of select="@description"/></li>
    </ul>
    <br/><br/><br/><br/>
  </xsl:template>
</xsl:stylesheet>
